@@ -16,7 +16,7 @@ from conans.client.cmd.new import (conanfile_bare,
                                    _get_files_from_template_dir)
 
 conanfile = """from conans import CMake, tools
-from sense2 import Sense2File, parseRequires2Denpens
+from sense2 import Sense2File, parseRequires2Denpends
 import os
 
 class {package_name}Conan(Sense2File):
@@ -33,7 +33,7 @@ class {package_name}Conan(Sense2File):
     generators = "cmake"
     requires = ""
     
-    ## make deb setting
+    ## deb setting
     deb_control = {{
        "Package": name,
        "Version": version,
@@ -43,10 +43,10 @@ class {package_name}Conan(Sense2File):
        "Section": "custom",
        "Priority": "optional",
        "Essential": "no",
-       "Depends": parseRequires2Denpens(requires),
+       "Depends": parseRequires2Denpends(requires),
        "Homepage": "www.example.com",
     }}
-    changelog = "my changelog test"
+    deb_changelog = "my changelog"
     
     ## user and channel for uploading cpp package to artifactory
     # user="user"
