@@ -4,9 +4,12 @@ from sense2.model.layout import Folders
 
 class Sense2File(ConanFile):
 
-    apt_user = ""
-    apt_server = ""
-
+    deb_control = None
+    deb_changelog = None
+    
+    apt_user = None
+    apt_server = None
+    
     def __init__(self, output, runner, display_name="", user=None, channel=None):
         super().__init__(output, runner, display_name, user, channel)
         # layout() method related variables:
@@ -33,7 +36,7 @@ class Sense2File(ConanFile):
     def upload_deb(sef):
         pass
 
-def parseRequires2Denpens(requires):
+def parseRequires2Denpends(requires):
 
     deps = []
     import re
